@@ -5,8 +5,8 @@
 class CodeGenerator {
 public:
     CodeGenerator(const QString &headers, const QString &code);
-    QString generateMainFunc() const;
-    QString generateMainFuncSafe() const;
+    QString generateMainFunc(bool safety = false) const;
+    //QString generateMainFuncSafe() const;
 
 private:
     QString _headers;
