@@ -4,6 +4,9 @@
 Print &Print::globalInstance()
 {
     static Print global;
+#if QT_VERSION >= 0x060000
+    global.setEncoding(QStringConverter::System);
+#endif
     global.flush();
     return global;
 }
